import { ReactElement, useState } from 'react';

import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { NsIcon, NsIconNameType, NsLink } from '../';

type NsCheckoutCardProps = {
    icon: NsIconNameType;
    title: string;
    linkText: string;
    url: string;
    className?: string;
};

const CardContainer = styled(Box)`
    background-color: #fff;
    display: flex;
    max-width: 345px;
    height: auto;
    border: 2px solid #B2B2B2;
    border-radius: 2px;
    .left-bar {
        width: 4px;
        height: auto;
        background-color: #22D55C;
    }
    .content {
        display: flex;
        flex-direction: row;
        gap: 10px;
        margin: 10px;
        width: 100%;
    }
    .text-content {
        width: 100%;
    }
    .title {
        font-size: 14px;
        font-weight: 700;
    }
    .address {
        font-size: 13px;
        font-weight: 400;
    }
    .action-link {
        color: #7123D9;
        font-size: 14px;
        font-weight: 700;
        letter-spacing: 0.7;
    }
    .icon-right {
        margin-left: auto;
    }
    .icon {
        &:hover {
            cursor: pointer;
        }
    }
`;
    
export default function NsCheckoutCard({ title, icon, linkText, url, className }: NsCheckoutCardProps): ReactElement {
    const [dropdownIcon, setDropdownIcon] = useState(false);
    const handleClick = () => {
        setDropdownIcon(!dropdownIcon);
    };

    return (
        <CardContainer className={className} role="checkout-card" component="div" data-testid="checkout-card">
            <div className="left-bar"></div>
            <div className="content">
                <span>
                    <NsIcon name={icon} />
                </span>
                <div className="text-content">
                    <article className="title">{title}</article>
                    <article className="address">Address</article>
                    <NsLink className="action-link" href={url}>
                        {linkText}
                    </NsLink>
                </div>
                <span className="icon-right">
                    <NsIcon
                        name={dropdownIcon ? 'arrowUp' : 'arrowDown'}
                        className="icon"
                        onClick={handleClick}
                        testId="dropdown-icon"
                    />
                </span>
            </div>
        </CardContainer>
    );
}
